@@ -33,8 +33,7 @@ Internally ``MediaFile`` uses ``MediaField`` descriptors to access the
 data from the tags. In turn ``MediaField`` uses a number of
 ``StorageStyle`` strategies to handle format specific logic.
 """
-from __future__ import (division, absolute_import, print_function,
-                        unicode_literals)
+from __future__ import division, absolute_import, print_function
 
 import mutagen
 import mutagen.mp3
@@ -159,7 +158,8 @@ def _safe_cast(out_type, val):
         else:
             if not isinstance(val, basestring):
                 val = unicode(val)
-            match = re.match(r'[\+-]?[0-9\.]+', val.strip())
+            match = re.match(r'[\+-]?([0-9]+\.?[0-9]*|[0-9]*\.[0-9]+)',
+                             val.strip())
             if match:
                 val = match.group(0)
                 if val:
@@ -181,7 +181,7 @@ def _unpack_asf_image(data):
     of exceptions (out-of-bounds, etc.). We should clean this up
     sometime so that the failure modes are well-defined.
     """
-    type, size = struct.unpack_from(b'<bi', data)
+    type, size = struct.unpack_from('<bi', data)
     pos = 5
     mime = ""
     while data[pos:pos + 2] != b'\x00\x00':
@@ -201,7 +201,7 @@ def _unpack_asf_image(data):
 def _pack_asf_image(mime, data, type=3, description=""):
     """Pack image data for a WM/Picture tag.
     """
-    tag_data = struct.pack(b'<bi', type, len(data))
+    tag_data = struct.pack('<bi', type, len(data))
     tag_data += mime.encode("utf-16-le") + b'\x00\x00'
     tag_data += description.encode("utf-16-le") + b'\x00\x00'
     tag_data += data
@@ -211,14 +211,19 @@ def _pack_asf_image(mime, data, type=3, description=""):
 # iTunes Sound Check encoding.
 
 def _sc_decode(soundcheck):
-    """Convert a Sound Check string value to a (gain, peak) tuple as
+    """Convert a Sound Check bytestring value to a (gain, peak) tuple as
     used by ReplayGain.
     """
+    # We decode binary data. If one of the formats gives us a text
+    # string, interpret it as UTF-8.
+    if isinstance(soundcheck, unicode):
+        soundcheck = soundcheck.encode('utf8')
+
     # SoundCheck tags consist of 10 numbers, each represented by 8
     # characters of ASCII hex preceded by a space.
     try:
         soundcheck = soundcheck.replace(b' ', b'').decode('hex')
-        soundcheck = struct.unpack(b'!iiiiiiiiii', soundcheck)
+        soundcheck = struct.unpack('!iiiiiiiiii', soundcheck)
     except (struct.error, TypeError):
         # SoundCheck isn't in the format we expect, so return default
         # values.
@@ -274,8 +279,8 @@ def _sc_encode(gain, peak):
 
 def _wider_test_jpeg(data):
     """Test for a jpeg file following the UNIX file implementation which
-    uses the magic bytes rather than just looking for the bytes b'JFIF'
-    or b'EXIF' at a fixed position.
+    uses the magic bytes rather than just looking for the bytes that
+    represent 'JFIF' or 'EXIF' at a fixed position.
     """
     if data[:2] == b'\xff\xd8':
         return 'jpeg'
@@ -645,13 +650,13 @@ class MP4BoolStorageStyle(MP4StorageStyle):
             return None
 
     def get_list(self, mutagen_file):
-        raise NotImplementedError('MP4 bool storage does not support lists')
+        raise NotImplementedError(u'MP4 bool storage does not support lists')
 
     def set(self, mutagen_file, value):
         mutagen_file[self.key] = value
 
     def set_list(self, mutagen_file, values):
-        raise NotImplementedError('MP4 bool storage does not support lists')
+        raise NotImplementedError(u'MP4 bool storage does not support lists')
 
 
 class MP4ImageStorageStyle(MP4ListStorageStyle):
@@ -669,7 +674,7 @@ class MP4ImageStorageStyle(MP4ListStorageStyle):
         elif image.mime_type == 'image/jpeg':
             kind = mutagen.mp4.MP4Cover.FORMAT_JPEG
         else:
-            raise ValueError('MP4 files only supports PNG and JPEG images')
+            raise ValueError(u'MP4 files only supports PNG and JPEG images')
         return mutagen.mp4.MP4Cover(image.data, kind)
 
 
@@ -1065,7 +1070,7 @@ class MediaField(object):
                          getting this property.
 
         """
-        self.out_type = kwargs.get(b'out_type', unicode)
+        self.out_type = kwargs.get('out_type', unicode)
         self._styles = styles
 
     def styles(self, mutagen_file):
@@ -1129,7 +1134,7 @@ class ListMediaField(MediaField):
         """Returns a ``MediaField`` descriptor that gets and sets the
         first item.
         """
-        options = {b'out_type': self.out_type}
+        options = {'out_type': self.out_type}
         return MediaField(*self._styles, **options)
 
 
@@ -1150,7 +1155,7 @@ class DateField(MediaField):
         storage styles do not return a value.
         """
         super(DateField, self).__init__(*date_styles)
-        year_style = kwargs.get(b'year', None)
+        year_style = kwargs.get('year', None)
         if year_style:
             self._year_field = MediaField(*year_style)
 
@@ -1359,11 +1364,11 @@ class MediaFile(object):
                 # anywhere else.
                 raise
             else:
-                log.debug('{}', traceback.format_exc())
+                log.debug(u'{}', traceback.format_exc())
                 raise MutagenError(path, exc)
         except Exception as exc:
             # Isolate bugs in Mutagen.
-            log.debug('{}', traceback.format_exc())
+            log.debug(u'{}', traceback.format_exc())
             log.error(u'uncaught Mutagen exception in open: {0}', exc)
             raise MutagenError(path, exc)
 
@@ -1436,7 +1441,7 @@ class MediaFile(object):
             # Propagate these through: they don't represent Mutagen bugs.
             raise
         except Exception as exc:
-            log.debug('{}', traceback.format_exc())
+            log.debug(u'{}', traceback.format_exc())
             log.error(u'uncaught Mutagen exception in save: {0}', exc)
             raise MutagenError(self.path, exc)
 
