@@ -16,8 +16,7 @@
 """Generates smart playlists based on beets queries.
 """
 
-from __future__ import (division, absolute_import, print_function,
-                        unicode_literals)
+from __future__ import division, absolute_import, print_function
 
 from beets.plugins import BeetsPlugin
 from beets import ui
@@ -46,9 +45,11 @@ class SmartPlaylistPlugin(BeetsPlugin):
             self.register_listener('database_change', self.db_change)
 
     def commands(self):
-        spl_update = ui.Subcommand('splupdate',
-                                   help='update the smart playlists. Playlist '
-                                        'names may be passed as arguments.')
+        spl_update = ui.Subcommand(
+            'splupdate',
+            help=u'update the smart playlists. Playlist names may be '
+            u'passed as arguments.'
+        )
         spl_update.func = self.update_cmd
         return [spl_update]
 
@@ -64,9 +65,10 @@ class SmartPlaylistPlugin(BeetsPlugin):
                             for name, q, a_q in self._unmatched_playlists
                             if name in args)
             if not playlists:
-                raise ui.UserError('No playlist matching any of {0} '
-                                   'found'.format([name for name, _, _ in
-                                                   self._unmatched_playlists]))
+                raise ui.UserError(
+                    u'No playlist matching any of {0} found'.format(
+                        [name for name, _, _ in self._unmatched_playlists])
+                )
 
             self._matched_playlists = playlists
             self._unmatched_playlists -= playlists
@@ -95,7 +97,7 @@ class SmartPlaylistPlugin(BeetsPlugin):
 
         for playlist in self.config['playlists'].get(list):
             if 'name' not in playlist:
-                self._log.warn("playlist configuration is missing name")
+                self._log.warn(u"playlist configuration is missing name")
                 continue
 
             playlist_data = (playlist['name'],)
@@ -131,7 +133,7 @@ class SmartPlaylistPlugin(BeetsPlugin):
                     playlist_data += (query_and_sort,)
 
             except ParsingError as exc:
-                self._log.warn("invalid query in playlist {}: {}",
+                self._log.warn(u"invalid query in playlist {}: {}",
                                playlist['name'], exc)
                 continue
 
@@ -151,14 +153,15 @@ class SmartPlaylistPlugin(BeetsPlugin):
         for playlist in self._unmatched_playlists:
             n, (q, _), (a_q, _) = playlist
             if self.matches(model, q, a_q):
-                self._log.debug("{0} will be updated because of {1}", n, model)
+                self._log.debug(
+                    u"{0} will be updated because of {1}", n, model)
                 self._matched_playlists.add(playlist)
                 self.register_listener('cli_exit', self.update_playlists)
 
         self._unmatched_playlists -= self._matched_playlists
 
     def update_playlists(self, lib):
-        self._log.info("Updating {0} smart playlists...",
+        self._log.info(u"Updating {0} smart playlists...",
                        len(self._matched_playlists))
 
         playlist_dir = self.config['playlist_dir'].as_filename()
@@ -196,4 +199,4 @@ class SmartPlaylistPlugin(BeetsPlugin):
                 with open(syspath(m3u_path), 'w') as f:
                     for path in m3us[m3u]:
                         f.write(path + b'\n')
-        self._log.info("{0} playlists updated", len(self._matched_playlists))
+        self._log.info(u"{0} playlists updated", len(self._matched_playlists))
